@@ -4,7 +4,7 @@ import pyonr
 import os
 from getpass import getpass
 from bcrypt import checkpw
-from app import create_app
+from server import create_app
 
 from notdb_viewer import __version__ as v
 
